@@ -1,5 +1,6 @@
 from typing import Dict, List, Any, Union
 
+from tqdm import tqdm
 import numpy as np
 import pandas as pd
 import scipy as sp
@@ -50,7 +51,9 @@ def determine_scaling(
     for _, batch in batches.items():
         if settings["robust"]:
             # TODO: consider f_iqr feature here. Would that work?
-            rnge = batch[columns_to_align].quantile(0.98) - batch[columns_to_align].quantile(0.02)
+            rnge = batch[columns_to_align].quantile(0.98) - batch[
+                columns_to_align
+            ].quantile(0.02)
         else:
             rnge = batch[columns_to_align].max() - batch[columns_to_align].min()
 
@@ -130,7 +133,9 @@ def reverse_scaling(
     for batch_id, batch in batches.items():
         out[batch_id] = batch[columns_to_align].copy()
         for tag, column in out[batch_id].iteritems():
-            out[batch_id][tag] = column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
+            out[batch_id][tag] = (
+                column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
+            )
     return out
 
 
@@ -235,7 +240,10 @@ def one_iteration_dtw(
     distances = []
     average_batch = refbatch_sc.copy().reset_index(drop=True) * 0.0
     successful_alignments = 0
-    for batch_id, batch in batches_scaled.items():
+
+    for batch_id, batch in tqdm(
+        batches_scaled.items(), disable=not (settings["show_progress"])
+    ):
         try:
             # see Kassidas, page 180
             batch_subset = batch.iloc[:: int(settings["subsample"]), :]
@@ -250,9 +258,7 @@ def one_iteration_dtw(
                     "Normalized distance": result.normalized_distance,
                 }
             )
-            if settings["show_progress"]:
-                message = f"  * {batch_id}: distance = {result.distance}"
-                print(message)
+
         except ValueError:
             assert False, f"Failed on batch {batch_id}"
 
@@ -325,7 +331,9 @@ def batch_dtw(
         default_settings.update(settings)
     settings = default_settings
     assert settings["maximum_iterations"] >= 3, "At least 3 iterations are required"
-    assert reference_batch in batches, "`reference_batch` was not found in the dict of batches."
+    assert (
+        reference_batch in batches
+    ), "`reference_batch` was not found in the dict of batches."
 
     assert check_valid_batch_dict(batches, no_nan=True)
 
@@ -364,7 +372,9 @@ def batch_dtw(
         # Deviations from the average batch:
         next_weights = np.zeros((1, refbatch_sc.shape[1]))
         for batch_id, result in aligned_batches.items():
-            next_weights += np.nansum(np.power(result.synced - average_batch, 2), axis=0)
+            next_weights += np.nansum(
+                np.power(result.synced - average_batch, 2), axis=0
+            )
             # TODO: use quadratic weights for now, but try sum of the absolute values instead
             #  np.abs(result.synced - average_batch).sum(axis=0)
 
@@ -377,7 +387,9 @@ def batch_dtw(
             # problematic_threshold = dist_df["Distance"].quantile(0.95)
 
         next_weights = 1.0 / np.where(next_weights > epsqrt, next_weights, 10000)
-        weight_vector = (next_weights / np.sum(next_weights) * len(columns_to_align)).ravel()
+        weight_vector = (
+            next_weights / np.sum(next_weights) * len(columns_to_align)
+        ).ravel()
         # If change in delta_weight is small, we terminate early; no need to fine-tune excessively.
         delta_weight = np.diag(weight_matrix) - weight_vector  # old - new
 
@@ -391,10 +403,11 @@ def batch_dtw(
         settings["interpolate_time_axis_delta"],
     )
 
-    for batch_id, result in aligned_batches.items():
-        if settings["show_progress"]:
-            message = f"Iterpolating values for batch = {batch_id}"
-            print(message)
+    for batch_id, result in tqdm(
+        aligned_batches.items(),
+        desc="Iterpolating",
+        disable=not (settings["show_progress"]),
+    ):
 
         initial_row = batches[batch_id].iloc[result.md_path[0, 0], :].copy()
         synced = align_with_path(
@@ -405,7 +418,8 @@ def batch_dtw(
         # Resample the trajectories of the aligned data now along this sequence.
         sequence = np.linspace(
             0,
-            settings["interpolate_time_axis_maximum"] - settings["interpolate_time_axis_delta"],
+            settings["interpolate_time_axis_maximum"]
+            - settings["interpolate_time_axis_delta"],
             synced.shape[0],
         )
         assert new_time_axis.min() == sequence.min()
@@ -525,14 +539,18 @@ def find_average_length(batches: Dict[str, pd.DataFrame], settings: dict = None)
         default_settings.update(settings)
     settings = default_settings
 
-    batch_lengths = pd.Series({batch_id: df.shape[0] for batch_id, df in batches.items()})
+    batch_lengths = pd.Series(
+        {batch_id: df.shape[0] for batch_id, df in batches.items()}
+    )
     if settings["robust"]:
         # If multiple batches of the median length, return the last one.
         return batch_lengths.index[
             np.where((batch_lengths == batch_lengths.median()).values)[0][-1]
         ]
     else:
-        return batch_lengths.index[(batch_lengths - batch_lengths.mean()).abs().argmin()]
+        return batch_lengths.index[
+            (batch_lengths - batch_lengths.mean()).abs().argmin()
+        ]
 
 
 def find_reference_batch(
